#!/usr/bin/env python

import socket

class Port:
    def __init__(self, data):
        #TCP_IP = '127.0.0.1' # <-- IP of the Server on Elvis
        #TCP_IP = '192.168.0.11' # <-- IP of the Server on Windows different comp
        TCP_IP = '192.168.0.5' # <-- IP of the Server on Windows same comp
        TCP_PORT = 5005
        BUFFER_SIZE = 1024
        #MESSAGE = 'Hello, World from Group A-2!'

        self.s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        self.s.connect((TCP_IP, TCP_PORT))
        self.transmit_data(data)
        #s.send(MESSAGE)
    def __del__(self):
        self.s.close()

    def transmit_data(self, data):
        self.s.send(data.encode())



#code to be run on the server end

#!/usr/bin/env python

import socket
from datetime import datetime
now = datetime.now()

def Log(text, addr):
	fileName = str(addr)
	fileName = fileName + ".txt"
	with open(fileName, "a") as logFile: # "a" stays for append mode
		logFile.write(text)
		logFile.write("\n")
		logFile.close()

TCP_IP = ''
TCP_PORT = 5005
BUFFER_SIZE = 1024

s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
s.bind((TCP_IP, TCP_PORT))
s.listen(1)

conn, addr = s.accept()
print('Connection address ', addr)
Log("Connection Opened: " + datetime.now().strftime("%d/%m/%Y %H:%M:%S"), addr)
print("received data:")
while 1:
    data = conn.recv(BUFFER_SIZE)
    if not data: break
    output = data.decode()
    print(output)
    Log(output, addr)
conn.close()
Log("Connection closed: " + datetime.now().strftime("%d/%m/%Y %H:%M:%S"), addr)





class Trojan: 
	def main():
		return 0

	def Encrypt(self, data):
		s=7 #shift
		cipher = ""
		
		for char in data:
			#uppercase letter
			if(char.isupper()):
				cipher += chr((ord(char) + s-65) % 26 + 65)
			#lowercase letter
			elif(char.islower()):
				cipher += chr((ord(char) + s-97) % 26 + 97)
			#non-letter characters are kept the same
			else:
				cipher += char
		return cipher

	def Decrypt(self, cipher):
		s=7 #shift
		data = ""
		
		for char in cipher:
			#uppercase letters
			if(char.isupper()):
				data += chr((ord(char) - s-65) % 26 + 65)
			#lowercase letters
			elif(char.islower()):
				data += chr((ord(char) - s-97) % 26 + 97)
			#non-letter characters are kept the same
			else:
				data += char
		return data

	def Hash(self, data):
		hash_size = 20  # fixed size of hash value
		hash_value = ""
		salt = 'asdfghjklpoiuytrewqzxcvbnm1234567890'
		#check the length of input data
		if len(data) <= hash_size:   
			add_len = hash_size - len(data) # length of the salt to be added
			hash_value = salt[0:(add_len//2)] + data + salt[(add_len//2):]
			hash_value = hash_value[:20]
		else:
			hash_value = data[:20]
		return hash_value


	


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()


setuptools.setup(
    name='PythonTrojanHorse',  
    version='0.1',
    author="Michael Wright, Aaron Youch, Petro Skrypnyk, Brandon Krupinski, Bryan Hill, Jaysson Solano",
    author_email="skrypn62@students.rowan.edu",
    description="Trojan Horse application",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/aaronyouch/PythonTrojanHorse",
    packages=setuptools.find_packages(),
    classifiers=[
         "Programming Language :: Python :: 3",
         "License :: OSI Approved :: MIT License",
         "Operating System :: OS Independent",
     ],
 )